# [dockeree](https://github.com/dclong/dockeree)

Make it easy to build and manager Docker images.
    
## Supported Operating Systems and Python Versions

| OS      | Python 3.7 | Python 3.8 | Python 3.9 | Python 3.10 |
|---------|------------|------------|------------|-------------|
| Linux   | Y          | Y          | Y          | Y           |
| macOS   | Y          | Y          | Y          | Y           |
| Windows | Y          | Y          | Y          | Y           |

## Installation

You can download a copy of the latest release and install it using pip.
```bash
pip3 install dockeree
```
